@@ -2,24 +2,21 @@
  * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
+ *
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
- * 
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
+ *
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -2766,10 +2763,20 @@ void IOFireWireSBP2Login::fetchAgentWriteComplete( IOReturn status, IOFireWireNu
 
 	if( fLastORB != NULL )
 	{
+	
 		UInt32 retries = fLastORB->getFetchAgentWriteRetries();
-		if( status != kIOReturnSuccess && status != kIOFireWireBusReset && retries != 0 )
+		int ack = fFetchAgentWriteCommand->getAckCode();
+	
+		if( ( ack == kFWAckBusyX || 
+			  ack == kFWAckBusyA ||
+			  ack == kFWAckBusyB ||
+			  ack == kFWAckDataError ) &&
+			  status != kIOReturnSuccess && 
+			  status != kIOFireWireBusReset && 
+			  retries != 0 )
 		{
-			IOLog( "IOFireWireSBP2Login::fetchAgentWriteComplete fetch agent write failed! retrying\n" );
+
+//			IOLog( "IOFireWireSBP2Login::fetchAgentWriteComplete fetch agent write failed! retrying\n" );
 #if PANIC_ON_DOUBLE_APPEND			
 			panic( "IOFireWireSBP2Login::fetchAgentWriteComplete fetch agent write failed!\n" );
 #endif			
@@ -2780,8 +2787,13 @@ void IOFireWireSBP2Login::fetchAgentWriteComplete( IOReturn status, IOFireWireNu
 			appendORBImmediate( fLastORB );
 			return;
 		}
+		
     }
 	
+	//
+	// check if we have an orb waiting to be appended
+	//
+	
 	fORBToWrite = 0; // no more orb pending a fetch agent write
 	
 	// theoretically fORBToWrite should already be cleared to zero 
