@@ -2,24 +2,21 @@
  * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
+ *
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
- * 
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
+ *
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -71,6 +68,19 @@ bool IOFireWireSBP2Target::start( IOService *provider )
     if (fProviderUnit == NULL)
         return false;
 
+	// we want the expansion data member to be zeroed if it's available 
+	// so create and zero in a local then assign to the member when were done
+	
+	ExpansionData * exp_data = (ExpansionData*) IOMalloc( sizeof(ExpansionData) );
+	if( !exp_data )
+	{
+		return false;
+	}
+
+	bzero( exp_data, sizeof(ExpansionData) );
+	
+	fExpansionData = exp_data;
+	
 	fControl = fProviderUnit->getController();
 	
 	// assume safe mode
@@ -164,6 +174,9 @@ bool IOFireWireSBP2Target::start( IOService *provider )
         return false;
 
     FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : started\n", (UInt32)this ) );
+	
+	fExpansionData->fStarted = true;
+	
     return true;
 }
 
@@ -196,7 +209,13 @@ void IOFireWireSBP2Target::free( void )
 		fIOCriticalSectionCount--;
 		fControl->enableSoftwareBusResets();
 	}
-	
+
+	if( fExpansionData )
+	{
+		IOFree( fExpansionData, sizeof(ExpansionData) );
+		fExpansionData = NULL;
+	}
+		
 	IOService::free();
 }
 
@@ -850,6 +869,15 @@ void IOFireWireSBP2Target::configurePhysicalFilter( void )
 {
     bool disablePhysicalAccess = false;
     
+	// sometimes message() gets called before start completes
+	// we shouldn't try to configure anything until start is done
+	
+	if( fExpansionData == NULL )
+		return;
+		
+	if( !fExpansionData->fStarted )
+		return;
+		
     //
     // determine if we should turn off physical access
     //
